document.addEventListener("DOMContentLoaded", () => {
    // Create an instance of RPSHandler
    const handler = new RPSHandler();

    // Register the images for mouseover and mouseout events
    const imgs = document.querySelectorAll(".player img");    
    for (let img of imgs) {
        img.addEventListener("mouseover", handler);
        img.addEventListener("mouseout", handler);
    }

    // Register the buttons for click events
    const buttons = document.querySelectorAll(".player button");
    for (let btn of buttons) {
        btn.addEventListener("click", handler);
    }
});

class RPSHandler {
    constructor() {
        this.results = ["Computer Wins!", "Player Wins!", "Tie!!"];
        this.moves = [
            {
                name: "rock",
                beatBy: "paper",
                beats: "scissors",
                img: "rock.png" // Update path if necessary
            },
            {
                name: "paper",
                beatBy: "scissors",
                beats: "rock",
                img: "paper.png" // Update path if necessary
            },
            {
                name: "scissors",
                beatBy: "rock",
                beats: "paper",
                img: "scissors.png" // Update path if necessary
            }
        ];
        this.computer = null;
        this.player = null;
    }

    getComputerMove() {
        return this.moves[Math.floor(Math.random() * this.moves.length)];
    }

    handleEvent(event) {
        const infoDiv = document.querySelector(".info-div");

        if (event.type === "mouseover") {
            // Display move information on mouseover
            const move = this.moves.find(mv => mv.name === event.target.alt);
            infoDiv.querySelector("div:first-child > span:last-child").textContent = move.name;
            infoDiv.querySelector("div:nth-child(2) > span:last-child").textContent = move.beats;
            infoDiv.querySelector("div:last-child > span:last-child").textContent = move.beatBy;
            infoDiv.classList.remove("hide");

        } else if (event.type === "mouseout") {
            // Hide the info div on mouseout
            infoDiv.classList.add("hide");

        } else if (event.type === "click") {
            // Get a random move for the computer on click
            this.computer = this.getComputerMove();
            const compImg = document.querySelector("#computer img");
            compImg.src = this.computer.img;
            compImg.alt = this.computer.name;
        }
    }
}
